==> adsprod-convert-1.1.8.4-sources.jar: com/bxm/adsprod/convert/ticket/TicketConvert.java <==
package com.bxm.adsprod.convert.ticket;

import com.bxm.adsprod.facade.ticket.Ticket;
import com.bxm.adsprod.facade.ticket.TicketCache;
import com.bxm.adsprod.facade.ticket.TicketOfRules;
import com.bxm.warcar.utils.TypeHelper;
import com.google.common.base.Preconditions;

/**
 * @author allen
 * @since V1.0.0 2017/12/28
 */
public final class TicketConvert {

    private TicketConvert() {}

    public static Ticket convert2Ticket(TicketOfRules orig) {
        Preconditions.checkNotNull(orig);
        Ticket dest = new Ticket();
        dest.setId(orig.getId());
        dest.setName(orig.getName());
        dest.setAdvertiser(orig.getAdvertiser());
        dest.setSettleType(orig.getSettleType());
        dest.setPrice(orig.getPrice());
        dest.setType(orig.getType());
        dest.setBudgetDaily(orig.getBudgetDaily());
        dest.setDomainCode(orig.getDomainCode());
        dest.setStandaloneCost(orig.getStandaloneCost());
        dest.setUrl(orig.getUrl());
        dest.setValidStartDate(orig.getValidStartDate());
        dest.setValidEndDate(orig.getValidEndDate());
        dest.setIsSupportWechat(orig.getIsSupportWechat());
        dest.setUserGradePassScore(orig.getUserGradePassScore());
        dest.setStatus(orig.getStatus());
        dest.setPauseReason(orig.getPauseReason());
        dest.setOss(orig.getOss());
        dest.setTags(orig.getTags());
        dest.setOnoffs(orig.getOnoffs());
        dest.setPrices(orig.getPrices());
        dest.setMifs(orig.getMifs());
        dest.setCpaPrice(orig.getCpaPrice());
        dest.setFloorPrice(orig.getFloorPrice());
        dest.setOcpc(orig.getOcpc());
        dest.setCloseThreshold(orig.getCloseThreshold());
        dest.setGroupId(orig.getGroupId());
        return dest;
    }

    public static TicketCache convert2TicketCache(Ticket orig) {
        Preconditions.checkNotNull(orig);
        TicketCache dest = new TicketCache();
        dest.setId(orig.getId());
        dest.setIsSupportWechat(orig.getIsSupportWechat());
        dest.setUserGradePassScore(orig.getUserGradePassScore());
        dest.setDomainCode(orig.getDomainCode());
        dest.setType(orig.getType());
        dest.setOss(orig.getOss());
        dest.setTags(orig.getTags());
        dest.setOnoffs(orig.getOnoffs());
        dest.setStatus(orig.getStatus());
        dest.setPauseReason(orig.getPauseReason());
        dest.setCpaPrice(orig.getCpaPrice());
        dest.setFloorPrice(orig.getFloorPrice());
        dest.setOcpc(TypeHelper.castToInt(orig.getOcpc()));
        dest.setCloseThreshold(orig.getCloseThreshold());
        dest.setGroupId(orig.getGroupId());
        return dest;
    }
}

==> adsprod-convert-2.8.4-sources.jar: com/bxm/adsprod/convert/ticket/TicketConvert.java <==
package com.bxm.adsprod.convert.ticket;

import com.bxm.adsprod.facade.ticket.Ticket;
import com.bxm.adsprod.facade.ticket.TicketCache;
import com.bxm.adsprod.facade.ticket.TicketOfRules;
import com.bxm.warcar.utils.TypeHelper;
import com.google.common.base.Preconditions;

import java.util.Date;

/**
 * @author allen
 * @since V1.0.0 2017/12/28
 */
public final class TicketConvert {

    private TicketConvert() {}

    public static Ticket convert2Ticket(TicketOfRules orig) {
        Preconditions.checkNotNull(orig);
        Ticket dest = new Ticket();
        dest.setId(orig.getId());
        dest.setName(orig.getName());
        dest.setAdvertiser(orig.getAdvertiser());
        dest.setSettleType(orig.getSettleType());
        dest.setPrice(orig.getPrice());
        dest.setType(orig.getType());
        dest.setBudgetDaily(orig.getBudgetDaily());
        dest.setDomainCode(orig.getDomainCode());
        dest.setStandaloneCost(orig.getStandaloneCost());
        dest.setUrl(orig.getUrl());
        dest.setValidStartDate(orig.getValidStartDate());
        dest.setValidEndDate(orig.getValidEndDate());
        dest.setIsSupportWechat(orig.getIsSupportWechat());
        dest.setUserGradePassScore(orig.getUserGradePassScore());
        dest.setStatus(orig.getStatus());
        dest.setPauseReason(orig.getPauseReason());
        dest.setOss(orig.getOss());
        dest.setTags(orig.getTags());
        dest.setOnoffs(orig.getOnoffs());
        dest.setPrices(orig.getPrices());
        dest.setMifs(orig.getMifs());
        dest.setCpaPrice(orig.getCpaPrice());
        dest.setFloorPrice(orig.getFloorPrice());
        dest.setOcpc(orig.getOcpc());
        dest.setCloseThreshold(orig.getCloseThreshold());
        dest.setGroupId(orig.getGroupId());
        dest.setApps(orig.getApps());
        dest.setConsumeModal(orig.getConsumeModal());
        dest.setUpdateTime(new Date());
        dest.setAdTicketAppExtend(orig.getAdTicketAppExtend());
        dest.setPositionScenes(orig.getPositionScenes());
        dest.setAssetsDistribute(orig.getAssetsDistribute());
        dest.setRightsId(orig.getRightsId());
        dest.setKylinGroupId(orig.getKylinGroupId());
        return dest;
    }

    public static TicketCache convert2TicketCache(Ticket orig) {
        Preconditions.checkNotNull(orig);
        TicketCache dest = new TicketCache();
        dest.setId(orig.getId());
        dest.setIsSupportWechat(orig.getIsSupportWechat());
        dest.setUserGradePassScore(orig.getUserGradePassScore());
        dest.setDomainCode(orig.getDomainCode());
        dest.setType(orig.getType());
        dest.setOss(orig.getOss());
        dest.setTags(orig.getTags());
        dest.setOnoffs(orig.getOnoffs());
        dest.setStatus(orig.getStatus());
        dest.setPauseReason(orig.getPauseReason());
        dest.setCpaPrice(orig.getCpaPrice());
        dest.setFloorPrice(orig.getFloorPrice());
        dest.setOcpc(TypeHelper.castToInt(orig.getOcpc()));
        dest.setCloseThreshold(orig.getCloseThreshold());
        dest.setGroupId(orig.getGroupId());
        dest.setApps(orig.getApps());
        dest.setStandaloneCost(orig.getStandaloneCost());
        dest.setConsumeModal(orig.getConsumeModal());
        dest.setAdTicketAppExtend(orig.getAdTicketAppExtend());
        dest.setPositionScenes(orig.getPositionScenes());
        dest.setAssetsDistribute(orig.getAssetsDistribute());
        dest.setTimesEnlargeDate(orig.getTimesEnlargeDate());
        dest.setRightsId(orig.getRightsId());
        dest.setKylinGroupId(orig.getKylinGroupId());
        return dest;
    }
}
